{% extends "pretixcontrol/organizers/base.html" %}
{% load i18n %}
{% load bootstrap3 %}
{% block inner %}
    <h1>{% trans "Delete team assignment rule:" %} "{{ object.attribute }}" &rarr; {{ object.team }}</h1>
    <form action="" method="post" class="form-horizontal">
        {% csrf_token %}
        <p>{% trans "Are you sure you want to delete this rule?" %}</p>
        <div class="form-group submit-group">
            <a href="{% url "plugins:pretix_oidc:team_assignment_rules" organizer=request.organizer.slug %}"
               class="btn btn-default btn-cancel">
                {% trans "Cancel" %}
            </a>
            <button type="submit" class="btn btn-danger btn-save">
                {% trans "Delete" %}
            </button>
        </div>
    </form>
{% endblock %}
