# Generated by Django 3.0.10 on 2020-09-19 20:30

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("pretix_oidc", "0001_initial"),
    ]

    operations = [
        migrations.AddConstraint(
            model_name="oidcteamassignmentrule",
            constraint=models.UniqueConstraint(
                fields=("team", "attribute", "value"), name="unique_rule"
            ),
        ),
    ]
