# Generated by Django 3.0.8 on 2020-07-22 22:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("pretixbase", "0162_remove_seat_name"),
    ]

    operations = [
        migrations.CreateModel(
            name="OIDCTeamAssignmentRule",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True, primary_key=True, serialize=False
                    ),
                ),
                ("attribute", models.CharField(max_length=255)),
                ("value", models.CharField(max_length=255)),
                (
                    "team",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="pretixbase.Team",
                    ),
                ),
            ],
            options={
                "verbose_name": "Team assignment rule",
            },
        ),
    ]
